"""
A package for parsing the JATS xml format using pydantic
"""
__version__ = "0.0.2"

from src.pyjats.structures import (
    Abbrev,
    AbbrevJournalTitle,
    Abs,
    Abstract,
    AccessDate,
    Ack,
    ActuateType,
    Address,
    AddrLine,
    Aff,
    AffAlternatives,
    Alternatives,
    AltText,
    AltTitle,
    And,
    Annotation1,
    Annotation2,
    AnnotationXml,
    AnnotationXmlModel,
    Anonymous,
    Answer,
    AnswerSet,
    App,
    AppGroup,
    Apply,
    ApplyContent,
    Approx,
    Arc,
    Arccos,
    Arccosh,
    Arccot,
    Arccoth,
    Arccsc,
    Arccsch,
    Arcsec,
    Arcsech,
    Arcsin,
    Arcsinh,
    Arctan,
    Arctanh,
    ArcType,
    Arg,
    Array,
    ArrayOrientation,
    Article,
    ArticleCategories,
    ArticleDtdVersion,
    ArticleId,
    ArticleMeta,
    ArticleTitle,
    ArticleVersion,
    ArticleVersionAlternatives,
    Attrib,
    AuthorComment,
    AuthorNotes,
    AwardDesc,
    AwardGroup,
    AwardId,
    AwardName,
    Back,
    BinaryLinalgClass,
    BinaryLogicalClass,
    BinaryRelnClass,
    BinarySetClass,
    Bind,
    BindContent,
    Bio,
    BlockAlternatives,
    Body,
    Bold,
    BoldToggle,
    BoxedText,
    BoxedTextOrientation,
    BoxedTextPosition,
    Break,
    Bvar,
    Caption,
    Card,
    Cartesianproduct,
    Cbytes,
    Ceiling,
    Cerror,
    ChapterTitle,
    ChemStruct,
    ChemStructWrap,
    ChemStructWrapOrientation,
    ChemStructWrapPosition,
    Ci,
    CiContent,
    CitationAlternatives,
    City,
    Cn,
    CnContent,
    Code,
    CodeExecutable,
    CodeOrientation,
    CodePosition,
    Codomain,
    Col,
    ColAlign,
    Colgroup,
    ColgroupAlign,
    ColgroupValign,
    Collab,
    CollabAlternatives,
    Columnalignstyle,
    ColValign,
    Comment,
    Complexes,
    Compose,
    CompoundKwd,
    CompoundKwdPart,
    CompoundSubject,
    CompoundSubjectPart,
    Condition,
    ConfAcronym,
    ConfDate,
    Conference,
    ConfLoc,
    ConfName,
    ConfNum,
    ConfSponsor,
    ConfTheme,
    Conjugate,
    ConstantArithClass,
    ConstantSetClass,
    Contrib,
    ContribCorresp,
    ContribDeceased,
    ContribEqualContrib,
    ContribGroup,
    ContribId,
    ContribIdAuthenticated,
    ContributedResourceGroup,
    CopyrightHolder,
    CopyrightStatement,
    CopyrightYear,
    Corresp,
    Cos,
    Cosh,
    Cot,
    Coth,
    Count,
    Country,
    Counts,
    Cs,
    Csc,
    Csch,
    Csymbol,
    CsymbolContent,
    Curl,
    CustomMeta,
    CustomMetaGroup,
    DataTitle,
    Date,
    DateInCitation,
    Day,
    Declare,
    DeclareOccurrence,
    Def,
    DefHead,
    DefItem,
    DefList,
    Degree,
    Degrees,
    DeprecatedContExp,
    Determinant,
    Diff,
    DifferentialOperatorClass,
    DispFormula,
    DispFormulaGroup,
    DispQuote,
    Divergence,
    Divide,
    Domain,
    Domainofapplication,
    Edition,
    ElementCitation,
    ElocationId,
    Email,
    Emptyset,
    Eq,
    EquationCount,
    Equivalent,
    Era,
    Etal,
    Eulergamma,
    Event,
    EventDesc,
    Exists,
    Exp,
    Explanation,
    Exponentiale,
    Extended,
    ExtendedBy,
    ExtLink,
    Factorial,
    Factorof,
    FalseType,
    Fax,
    Fig,
    FigCount,
    FigGroup,
    FigGroupOrientation,
    FigGroupPosition,
    FigOrientation,
    FigPosition,
    FixedCase,
    FloatsGroup,
    Floor,
    Fn1,
    Fn2,
    FnGroup,
    Forall,
    Fpage,
    Front,
    FrontStub,
    FundingGroup,
    FundingSource,
    FundingStatement,
    Gcd,
    Geq,
    GivenNames,
    Glossary,
    GlyphData,
    GlyphRef,
    Gov,
    Grad,
    Graphic,
    GraphicOrientation,
    GraphicPosition,
    GroupAlignment,
    Gt,
    History,
    Hr,
    Ident,
    Image,
    Imaginary,
    Imaginaryi,
    ImpliedMrow,
    Implies,
    In,
    IndexTerm,
    IndexTermRangeEnd,
    Infinity,
    InlineFormula,
    InlineGraphic,
    InlineMedia,
    InlineSupplementaryMaterial,
    Institution,
    InstitutionId,
    InstitutionWrap,
    Int,
    IntClass,
    Integers,
    Intersect,
    Interval,
    IntervalClass,
    Inverse,
    Isbn,
    Issn,
    IssnL,
    Issue,
    IssueId,
    IssuePart,
    IssueSponsor,
    IssueSubtitle,
    IssueTitle,
    IssueTitleGroup,
    Italic,
    ItalicToggle,
    JournalId,
    JournalMeta,
    JournalSubtitle,
    JournalTitle,
    JournalTitleGroup,
    Kwd,
    KwdGroup,
    Label,
    Lambda,
    LambdaClass,
    LangValue,
    Laplacian,
    Lcm,
    Leq,
    License,
    LicenseP,
    Limit,
    LimitClass,
    Linestyle,
    List1,
    List2,
    ListItem,
    ListOrder,
    Ln,
    Locator,
    LocatorType,
    Log,
    Logbase,
    LongDesc,
    Lowlimit,
    Lpage,
    Lt,
    Maction,
    MactionValue,
    MalignExpression,
    Maligngroup,
    MaligngroupGroupalign,
    MaligngroupValue,
    Malignmark,
    MalignmarkEdge,
    MalignmarkValue,
    Math,
    MathAccent,
    MathAccentunder,
    MathAlign,
    MathBevelled,
    MathCharalign,
    MathDenomalign,
    MathDir,
    MathDisplay,
    MathDisplaystyle,
    MathEdge,
    MathEqualcolumns,
    MathEqualrows,
    MathFence,
    MathForm,
    MathIndentalign,
    MathIndentalignfirst,
    MathIndentalignlast,
    MathInfixlinebreakstyle,
    MathLargeop,
    MathLinebreak,
    MathLinebreakstyle,
    MathLocation,
    MathLongdivstyle,
    MathMathvariant,
    MathMovablelimits,
    MathNumalign,
    MathOverflow,
    MathSeparator,
    MathSide,
    MathStackalign,
    MathStretchy,
    MathSymmetric,
    MathValue,
    Matrix,
    Matrixrow,
    Max,
    Mean,
    Media,
    Median,
    MediaOrientation,
    MediaPosition,
    Menclose,
    MencloseValue,
    Merror,
    MerrorValue,
    MetaName,
    MetaValue,
    Mfenced,
    MfencedValue,
    Mfrac,
    MfracBevelled,
    MfracDenomalign,
    MfracNumalign,
    MfracValue,
    Mglyph,
    MglyphFontstyle,
    MglyphFontweight,
    MglyphMathvariant,
    MglyphValue,
    Mi,
    MiDir,
    MiFontstyle,
    MiFontweight,
    MilestoneEnd,
    MilestoneStart,
    MiMathvariant,
    Min,
    Minus,
    MiValue,
    MixedCitation,
    Mlabeledtr,
    MlabeledtrRowalign,
    MlabeledtrValue,
    Mlongdiv,
    MlongdivLongdivstyle,
    MlongdivValue,
    Mmultiscripts,
    MmultiscriptsValue,
    Mn,
    MnDir,
    MnFontstyle,
    MnFontweight,
    MnMathvariant,
    MnValue,
    Mo,
    MoAccent,
    Mode,
    MoDir,
    MoFence,
    MoFontstyle,
    MoFontweight,
    MoForm,
    MoIndentalign,
    MoIndentalignfirst,
    MoIndentalignlast,
    MoLargeop,
    MoLinebreak,
    MoLinebreakstyle,
    MoMathvariant,
    Moment,
    Momentabout,
    MoMovablelimits,
    Monospace,
    MonospaceToggle,
    Month,
    MoSeparator,
    MoStretchy,
    MoSymmetric,
    MoValue,
    Mover,
    MoverAccent,
    MoverAlign,
    MoverValue,
    Mpadded,
    MpaddedValue,
    Mphantom,
    MphantomValue,
    Mprescripts,
    MprescriptsValue,
    Mroot,
    MrootValue,
    Mrow,
    MrowDir,
    MrowValue,
    Ms,
    Mscarries,
    MscarriesLocation,
    MscarriesValue,
    Mscarry,
    MscarryLocation,
    MscarryValue,
    MsDir,
    MsFontstyle,
    MsFontweight,
    Msgroup,
    MsgroupValue,
    Msline,
    MslineValue,
    MsMathvariant,
    Mspace,
    MspaceDir,
    MspaceFontstyle,
    MspaceFontweight,
    MspaceIndentalign,
    MspaceIndentalignfirst,
    MspaceIndentalignlast,
    MspaceLinebreak,
    MspaceMathvariant,
    MspaceValue,
    Msqrt,
    MsqrtValue,
    Msrow,
    MsrowValue,
    Mstack,
    MstackCharalign,
    MstackStackalign,
    MstackValue,
    Mstyle,
    MstyleAccent,
    MstyleAccentunder,
    MstyleAlign,
    MstyleBevelled,
    MstyleCharalign,
    MstyleDenomalign,
    MstyleDir,
    MstyleDisplaystyle,
    MstyleEdge,
    MstyleEqualcolumns,
    MstyleEqualrows,
    MstyleFence,
    MstyleFontstyle,
    MstyleFontweight,
    MstyleForm,
    MstyleIndentalign,
    MstyleIndentalignfirst,
    MstyleIndentalignlast,
    MstyleInfixlinebreakstyle,
    MstyleLargeop,
    MstyleLinebreak,
    MstyleLinebreakstyle,
    MstyleLocation,
    MstyleLongdivstyle,
    MstyleMathvariant,
    MstyleMovablelimits,
    MstyleNumalign,
    MstyleSeparator,
    MstyleSide,
    MstyleStackalign,
    MstyleStretchy,
    MstyleSymmetric,
    MstyleValue,
    Msub,
    Msubsup,
    MsubsupValue,
    MsubValue,
    Msup,
    MsupValue,
    MsValue,
    Mtable,
    MtableDisplaystyle,
    MtableEqualcolumns,
    MtableEqualrows,
    MtableSide,
    MtableValue,
    Mtd,
    Mtext,
    MtextDir,
    MtextFontstyle,
    MtextFontweight,
    MtextMathvariant,
    MtextValue,
    Mtr,
    MtrRowalign,
    MtrValue,
    Munder,
    MunderAccentunder,
    MunderAlign,
    Munderover,
    MunderoverAccent,
    MunderoverAccentunder,
    MunderoverAlign,
    MunderoverValue,
    MunderValue,
    Name,
    NameAlternatives,
    NamedContent,
    NameNameStyle,
    NaryArithClass,
    NaryConstructorClass,
    NaryFunctionalClass,
    NaryLinalgClass,
    NaryLogicalClass,
    NaryMinmaxClass,
    NaryRelnClass,
    NarySetClass,
    NarySetlistConstructorClass,
    NarySetRelnClass,
    NaryStatsClass,
    Naturalnumbers,
    Neq,
    NestedKwd,
    NlmCitation,
    NoneType,
    NoneValue,
    Not,
    Notanumber,
    Note,
    Notes,
    Notin,
    Notprsubset,
    Notsubset,
    ObjectId,
    OnBehalfOf,
    OpenAccess,
    Option,
    OptionCorrect,
    Or,
    Otherwise,
    Outerproduct,
    Overline,
    OverlineEnd,
    OverlineStart,
    OverlineToggle,
    P,
    PageCount,
    PageRange,
    Partialdiff,
    PartialdiffClass,
    PartTitle,
    Patent,
    Permissions,
    PersonGroup,
    Phone,
    Pi,
    Piece,
    Piecewise,
    Plus,
    PostalCode,
    Power,
    Prefix,
    Preformat,
    PreformatOrientation,
    PreformatPosition,
    PresentationExpression,
    Price,
    Primes,
    PrincipalAwardRecipient,
    PrincipalInvestigator,
    PrivateChar,
    ProcessingMeta,
    ProcessingMetaBaseTagset,
    ProcessingMetaMathmlVersion,
    ProcessingMetaTableModel,
    ProcessingMetaTagsetFamily,
    Product1,
    Product2,
    ProductClass,
    Prsubset,
    PubDate,
    PubDateNotAvailable,
    PubHistory,
    PubId,
    Publisher,
    PublisherLoc,
    PublisherName,
    QuantifierClass,
    Question,
    QuestionPreamble,
    QuestionQuestionResponseType,
    QuestionWrap,
    QuestionWrapGroup,
    Quotient,
    Rationals,
    Rb,
    Real,
    Reals,
    Ref,
    RefCount,
    RefList,
    RelatedArticle,
    RelatedObject,
    Reln,
    Rem,
    Resource,
    ResourceGroup,
    ResourceId,
    ResourceName,
    ResourceType,
    ResourceWrap,
    Response,
    RestrictedBy,
    Role,
    Roman,
    RomanToggle,
    Root,
    Rp,
    Rt,
    Ruby,
    SansSerif,
    SansSerifToggle,
    Sc,
    Scalarproduct,
    ScToggle,
    Sdev,
    Season,
    Sec1,
    Sec2,
    Sech,
    SecMeta,
    See,
    SeeAlso,
    Selector,
    SelfUri,
    Sep,
    Series,
    SeriesText,
    SeriesTitle,
    Set,
    Setdiff,
    Share,
    ShowType,
    Sig,
    SigBlock,
    Simple,
    Sin,
    Sinh,
    Size,
    Source,
    SpaceValue,
    Speaker,
    Speech,
    State,
    Statement,
    Std,
    StdOrganization,
    Strike,
    StrikeToggle,
    StringConf,
    StringDate,
    StringName,
    StringNameNameStyle,
    StyledContent,
    StyledContentToggle,
    Sub,
    SubArrange,
    SubArticle,
    Subject,
    SubjGroup,
    Subset,
    Subtitle,
    Suffix,
    Sum,
    SumClass,
    Sup,
    SupArrange,
    Supplement,
    SupplementaryMaterial,
    SupplementaryMaterialOrientation,
    SupplementaryMaterialPosition,
    SupportDescription,
    SupportGroup,
    SupportSource,
    Surname,
    Table,
    TableCellExpression,
    TableCellExpressionRowalign,
    TableCellExpressionValue,
    TableCount,
    TableFrame,
    TableRowExpression,
    TableRules,
    TableWrap,
    TableWrapFoot,
    TableWrapGroup,
    TableWrapGroupOrientation,
    TableWrapGroupPosition,
    TableWrapOrientation,
    TableWrapPosition,
    Tan,
    Tanh,
    Target,
    Tbody,
    TbodyAlign,
    TbodyValign,
    Td,
    TdAlign,
    TdScope,
    TdValign,
    Tendsto,
    Term,
    TermHead,
    TexMath,
    TexMathNotation,
    TextualForm,
    Tfoot,
    TfootAlign,
    TfootValign,
    Th,
    ThAlign,
    Thead,
    TheadAlign,
    TheadValign,
    ThScope,
    ThValign,
    Times,
    TimeStamp,
    Title,
    TitleAbstract,
    TitleEltType,
    TitleGroup,
    TokenExpression,
    Tr,
    TrAlign,
    TransAbstract,
    Transpose,
    TransSource,
    TransSubtitle,
    TransTitle,
    TransTitleGroup,
    TrueType,
    TrValign,
    TypeType,
    UnaryElementaryClass,
    UnaryFunctionalClass,
    UnaryLinalgClass,
    UnaryLogicalClass,
    UnarySetClass,
    UnaryVeccalcClass,
    Underline,
    UnderlineEnd,
    UnderlineStart,
    UnderlineToggle,
    UnionType,
    UnstructuredKwdGroup,
    Uplimit,
    Uri,
    Variance,
    Vector,
    Vectorproduct,
    VerseGroup,
    VerseLine,
    Version,
    Verticalalign,
    Volume,
    VolumeId,
    VolumeIssueGroup,
    VolumeSeries,
    WordCount,
    X,
    Xor,
    Xref,
    Year,
)

__all__ = [
    "DeprecatedContExp",
    "DifferentialOperatorClass",
    "ImpliedMrow",
    "MalignExpression",
    "PresentationExpression",
    "TableCellExpression",
    "TableCellExpressionRowalign",
    "TableCellExpressionValue",
    "TableRowExpression",
    "TokenExpression",
    "Abbrev",
    "AbbrevJournalTitle",
    "Abs",
    "Abstract",
    "AccessDate",
    "Ack",
    "ActuateType",
    "AddrLine",
    "Address",
    "Aff",
    "AffAlternatives",
    "AltText",
    "AltTitle",
    "Alternatives",
    "And",
    "AnnotationXml",
    "AnnotationXmlModel",
    "Annotation1",
    "Annotation2",
    "Anonymous",
    "Answer",
    "AnswerSet",
    "App",
    "AppGroup",
    "Apply",
    "ApplyContent",
    "Approx",
    "Arc",
    "ArcType",
    "Arccos",
    "Arccosh",
    "Arccot",
    "Arccoth",
    "Arccsc",
    "Arccsch",
    "Arcsec",
    "Arcsech",
    "Arcsin",
    "Arcsinh",
    "Arctan",
    "Arctanh",
    "Arg",
    "Array",
    "ArrayOrientation",
    "Article",
    "ArticleCategories",
    "ArticleId",
    "ArticleMeta",
    "ArticleTitle",
    "ArticleVersion",
    "ArticleVersionAlternatives",
    "ArticleDtdVersion",
    "Attrib",
    "AuthorComment",
    "AuthorNotes",
    "AwardDesc",
    "AwardGroup",
    "AwardId",
    "AwardName",
    "Back",
    "BinaryLinalgClass",
    "BinaryLogicalClass",
    "BinaryRelnClass",
    "BinarySetClass",
    "Bind",
    "BindContent",
    "Bio",
    "BlockAlternatives",
    "Body",
    "Bold",
    "BoldToggle",
    "BoxedText",
    "BoxedTextOrientation",
    "BoxedTextPosition",
    "Break",
    "Bvar",
    "Caption",
    "Card",
    "Cartesianproduct",
    "Cbytes",
    "Ceiling",
    "Cerror",
    "ChapterTitle",
    "ChemStruct",
    "ChemStructWrap",
    "ChemStructWrapOrientation",
    "ChemStructWrapPosition",
    "Ci",
    "CiContent",
    "CitationAlternatives",
    "City",
    "Cn",
    "CnContent",
    "Code",
    "CodeExecutable",
    "CodeOrientation",
    "CodePosition",
    "Codomain",
    "Col",
    "ColAlign",
    "ColValign",
    "Colgroup",
    "ColgroupAlign",
    "ColgroupValign",
    "Collab",
    "CollabAlternatives",
    "Columnalignstyle",
    "Comment",
    "Complexes",
    "Compose",
    "CompoundKwd",
    "CompoundKwdPart",
    "CompoundSubject",
    "CompoundSubjectPart",
    "Condition",
    "ConfAcronym",
    "ConfDate",
    "ConfLoc",
    "ConfName",
    "ConfNum",
    "ConfSponsor",
    "ConfTheme",
    "Conference",
    "Conjugate",
    "ConstantArithClass",
    "ConstantSetClass",
    "Contrib",
    "ContribGroup",
    "ContribId",
    "ContribIdAuthenticated",
    "ContribCorresp",
    "ContribDeceased",
    "ContribEqualContrib",
    "ContributedResourceGroup",
    "CopyrightHolder",
    "CopyrightStatement",
    "CopyrightYear",
    "Corresp",
    "Cos",
    "Cosh",
    "Cot",
    "Coth",
    "Count",
    "Country",
    "Counts",
    "Cs",
    "Csc",
    "Csch",
    "Csymbol",
    "CsymbolContent",
    "Curl",
    "CustomMeta",
    "CustomMetaGroup",
    "DataTitle",
    "Date",
    "DateInCitation",
    "Day",
    "Declare",
    "DeclareOccurrence",
    "Def",
    "DefHead",
    "DefItem",
    "DefList",
    "Degree",
    "Degrees",
    "Determinant",
    "Diff",
    "DispFormula",
    "DispFormulaGroup",
    "DispQuote",
    "Divergence",
    "Divide",
    "Domain",
    "Domainofapplication",
    "Edition",
    "ElementCitation",
    "ElocationId",
    "Email",
    "Emptyset",
    "Eq",
    "EquationCount",
    "Equivalent",
    "Era",
    "Etal",
    "Eulergamma",
    "Event",
    "EventDesc",
    "Exists",
    "Exp",
    "Explanation",
    "Exponentiale",
    "ExtLink",
    "Extended",
    "ExtendedBy",
    "Factorial",
    "Factorof",
    "FalseType",
    "Fax",
    "Fig",
    "FigCount",
    "FigGroup",
    "FigGroupOrientation",
    "FigGroupPosition",
    "FigOrientation",
    "FigPosition",
    "FixedCase",
    "FloatsGroup",
    "Floor",
    "FnGroup",
    "Fn1",
    "Fn2",
    "Forall",
    "Fpage",
    "Front",
    "FrontStub",
    "FundingGroup",
    "FundingSource",
    "FundingStatement",
    "Gcd",
    "Geq",
    "GivenNames",
    "Glossary",
    "GlyphData",
    "GlyphRef",
    "Gov",
    "Grad",
    "Graphic",
    "GraphicOrientation",
    "GraphicPosition",
    "GroupAlignment",
    "Gt",
    "History",
    "Hr",
    "Ident",
    "Image",
    "Imaginary",
    "Imaginaryi",
    "Implies",
    "In",
    "IndexTerm",
    "IndexTermRangeEnd",
    "Infinity",
    "InlineFormula",
    "InlineGraphic",
    "InlineMedia",
    "InlineSupplementaryMaterial",
    "Institution",
    "InstitutionId",
    "InstitutionWrap",
    "Int",
    "IntClass",
    "Integers",
    "Intersect",
    "Interval",
    "IntervalClass",
    "Inverse",
    "Isbn",
    "Issn",
    "IssnL",
    "Issue",
    "IssueId",
    "IssuePart",
    "IssueSponsor",
    "IssueSubtitle",
    "IssueTitle",
    "IssueTitleGroup",
    "Italic",
    "ItalicToggle",
    "JournalId",
    "JournalMeta",
    "JournalSubtitle",
    "JournalTitle",
    "JournalTitleGroup",
    "Kwd",
    "KwdGroup",
    "Label",
    "Lambda",
    "LambdaClass",
    "LangValue",
    "Laplacian",
    "Lcm",
    "Leq",
    "License",
    "LicenseP",
    "Limit",
    "LimitClass",
    "Linestyle",
    "ListItem",
    "List1",
    "List2",
    "ListOrder",
    "Ln",
    "Locator",
    "LocatorType",
    "Log",
    "Logbase",
    "LongDesc",
    "Lowlimit",
    "Lpage",
    "Lt",
    "Maction",
    "MactionValue",
    "Maligngroup",
    "MaligngroupGroupalign",
    "MaligngroupValue",
    "Malignmark",
    "MalignmarkEdge",
    "MalignmarkValue",
    "Math",
    "MathAccent",
    "MathAccentunder",
    "MathAlign",
    "MathBevelled",
    "MathCharalign",
    "MathDenomalign",
    "MathDir",
    "MathDisplay",
    "MathDisplaystyle",
    "MathEdge",
    "MathEqualcolumns",
    "MathEqualrows",
    "MathFence",
    "MathForm",
    "MathIndentalign",
    "MathIndentalignfirst",
    "MathIndentalignlast",
    "MathInfixlinebreakstyle",
    "MathLargeop",
    "MathLinebreak",
    "MathLinebreakstyle",
    "MathLocation",
    "MathLongdivstyle",
    "MathMathvariant",
    "MathMovablelimits",
    "MathNumalign",
    "MathOverflow",
    "MathSeparator",
    "MathSide",
    "MathStackalign",
    "MathStretchy",
    "MathSymmetric",
    "MathValue",
    "Matrix",
    "Matrixrow",
    "Max",
    "Mean",
    "Media",
    "MediaOrientation",
    "MediaPosition",
    "Median",
    "Menclose",
    "MencloseValue",
    "Merror",
    "MerrorValue",
    "MetaName",
    "MetaValue",
    "Mfenced",
    "MfencedValue",
    "Mfrac",
    "MfracBevelled",
    "MfracDenomalign",
    "MfracNumalign",
    "MfracValue",
    "Mglyph",
    "MglyphFontstyle",
    "MglyphFontweight",
    "MglyphMathvariant",
    "MglyphValue",
    "Mi",
    "MiDir",
    "MiFontstyle",
    "MiFontweight",
    "MiMathvariant",
    "MiValue",
    "MilestoneEnd",
    "MilestoneStart",
    "Min",
    "Minus",
    "MixedCitation",
    "Mlabeledtr",
    "MlabeledtrRowalign",
    "MlabeledtrValue",
    "Mlongdiv",
    "MlongdivLongdivstyle",
    "MlongdivValue",
    "Mmultiscripts",
    "MmultiscriptsValue",
    "Mn",
    "MnDir",
    "MnFontstyle",
    "MnFontweight",
    "MnMathvariant",
    "MnValue",
    "Mo",
    "MoAccent",
    "MoDir",
    "MoFence",
    "MoFontstyle",
    "MoFontweight",
    "MoForm",
    "MoIndentalign",
    "MoIndentalignfirst",
    "MoIndentalignlast",
    "MoLargeop",
    "MoLinebreak",
    "MoLinebreakstyle",
    "MoMathvariant",
    "MoMovablelimits",
    "MoSeparator",
    "MoStretchy",
    "MoSymmetric",
    "MoValue",
    "Mode",
    "Moment",
    "Momentabout",
    "Monospace",
    "MonospaceToggle",
    "Month",
    "Mover",
    "MoverAccent",
    "MoverAlign",
    "MoverValue",
    "Mpadded",
    "MpaddedValue",
    "Mphantom",
    "MphantomValue",
    "Mprescripts",
    "MprescriptsValue",
    "Mroot",
    "MrootValue",
    "Mrow",
    "MrowDir",
    "MrowValue",
    "Ms",
    "MsDir",
    "MsFontstyle",
    "MsFontweight",
    "MsMathvariant",
    "MsValue",
    "Mscarries",
    "MscarriesLocation",
    "MscarriesValue",
    "Mscarry",
    "MscarryLocation",
    "MscarryValue",
    "Msgroup",
    "MsgroupValue",
    "Msline",
    "MslineValue",
    "Mspace",
    "MspaceDir",
    "MspaceFontstyle",
    "MspaceFontweight",
    "MspaceIndentalign",
    "MspaceIndentalignfirst",
    "MspaceIndentalignlast",
    "MspaceLinebreak",
    "MspaceMathvariant",
    "MspaceValue",
    "Msqrt",
    "MsqrtValue",
    "Msrow",
    "MsrowValue",
    "Mstack",
    "MstackCharalign",
    "MstackStackalign",
    "MstackValue",
    "Mstyle",
    "MstyleAccent",
    "MstyleAccentunder",
    "MstyleAlign",
    "MstyleBevelled",
    "MstyleCharalign",
    "MstyleDenomalign",
    "MstyleDir",
    "MstyleDisplaystyle",
    "MstyleEdge",
    "MstyleEqualcolumns",
    "MstyleEqualrows",
    "MstyleFence",
    "MstyleFontstyle",
    "MstyleFontweight",
    "MstyleForm",
    "MstyleIndentalign",
    "MstyleIndentalignfirst",
    "MstyleIndentalignlast",
    "MstyleInfixlinebreakstyle",
    "MstyleLargeop",
    "MstyleLinebreak",
    "MstyleLinebreakstyle",
    "MstyleLocation",
    "MstyleLongdivstyle",
    "MstyleMathvariant",
    "MstyleMovablelimits",
    "MstyleNumalign",
    "MstyleSeparator",
    "MstyleSide",
    "MstyleStackalign",
    "MstyleStretchy",
    "MstyleSymmetric",
    "MstyleValue",
    "Msub",
    "MsubValue",
    "Msubsup",
    "MsubsupValue",
    "Msup",
    "MsupValue",
    "Mtable",
    "MtableDisplaystyle",
    "MtableEqualcolumns",
    "MtableEqualrows",
    "MtableSide",
    "MtableValue",
    "Mtd",
    "Mtext",
    "MtextDir",
    "MtextFontstyle",
    "MtextFontweight",
    "MtextMathvariant",
    "MtextValue",
    "Mtr",
    "MtrRowalign",
    "MtrValue",
    "Munder",
    "MunderAccentunder",
    "MunderAlign",
    "MunderValue",
    "Munderover",
    "MunderoverAccent",
    "MunderoverAccentunder",
    "MunderoverAlign",
    "MunderoverValue",
    "Name",
    "NameAlternatives",
    "NameNameStyle",
    "NamedContent",
    "NaryArithClass",
    "NaryConstructorClass",
    "NaryFunctionalClass",
    "NaryLinalgClass",
    "NaryLogicalClass",
    "NaryMinmaxClass",
    "NaryRelnClass",
    "NarySetRelnClass",
    "NarySetClass",
    "NarySetlistConstructorClass",
    "NaryStatsClass",
    "Naturalnumbers",
    "Neq",
    "NestedKwd",
    "NlmCitation",
    "NoneType",
    "NoneValue",
    "Not",
    "Notanumber",
    "Note",
    "Notes",
    "Notin",
    "Notprsubset",
    "Notsubset",
    "ObjectId",
    "OnBehalfOf",
    "OpenAccess",
    "Option",
    "OptionCorrect",
    "Or",
    "Otherwise",
    "Outerproduct",
    "Overline",
    "OverlineEnd",
    "OverlineStart",
    "OverlineToggle",
    "P",
    "PageCount",
    "PageRange",
    "PartTitle",
    "Partialdiff",
    "PartialdiffClass",
    "Patent",
    "Permissions",
    "PersonGroup",
    "Phone",
    "Pi",
    "Piece",
    "Piecewise",
    "Plus",
    "PostalCode",
    "Power",
    "Prefix",
    "Preformat",
    "PreformatOrientation",
    "PreformatPosition",
    "Price",
    "Primes",
    "PrincipalAwardRecipient",
    "PrincipalInvestigator",
    "PrivateChar",
    "ProcessingMeta",
    "ProcessingMetaBaseTagset",
    "ProcessingMetaMathmlVersion",
    "ProcessingMetaTableModel",
    "ProcessingMetaTagsetFamily",
    "ProductClass",
    "Product1",
    "Product2",
    "Prsubset",
    "PubDate",
    "PubDateNotAvailable",
    "PubHistory",
    "PubId",
    "Publisher",
    "PublisherLoc",
    "PublisherName",
    "QuantifierClass",
    "Question",
    "QuestionPreamble",
    "QuestionWrap",
    "QuestionWrapGroup",
    "QuestionQuestionResponseType",
    "Quotient",
    "Rationals",
    "Rb",
    "Real",
    "Reals",
    "Ref",
    "RefCount",
    "RefList",
    "RelatedArticle",
    "RelatedObject",
    "Reln",
    "Rem",
    "Resource",
    "ResourceGroup",
    "ResourceId",
    "ResourceName",
    "ResourceWrap",
    "ResourceType",
    "Response",
    "RestrictedBy",
    "Role",
    "Roman",
    "RomanToggle",
    "Root",
    "Rp",
    "Rt",
    "Ruby",
    "SansSerif",
    "SansSerifToggle",
    "Sc",
    "ScToggle",
    "Scalarproduct",
    "Sdev",
    "Season",
    "SecMeta",
    "Sec1",
    "Sec2",
    "Sech",
    "See",
    "SeeAlso",
    "Selector",
    "SelfUri",
    "Sep",
    "Series",
    "SeriesText",
    "SeriesTitle",
    "Set",
    "Setdiff",
    "Share",
    "ShowType",
    "Sig",
    "SigBlock",
    "Simple",
    "Sin",
    "Sinh",
    "Size",
    "Source",
    "SpaceValue",
    "Speaker",
    "Speech",
    "State",
    "Statement",
    "Std",
    "StdOrganization",
    "Strike",
    "StrikeToggle",
    "StringConf",
    "StringDate",
    "StringName",
    "StringNameNameStyle",
    "StyledContent",
    "StyledContentToggle",
    "Sub",
    "SubArticle",
    "SubArrange",
    "SubjGroup",
    "Subject",
    "Subset",
    "Subtitle",
    "Suffix",
    "Sum",
    "SumClass",
    "Sup",
    "SupArrange",
    "Supplement",
    "SupplementaryMaterial",
    "SupplementaryMaterialOrientation",
    "SupplementaryMaterialPosition",
    "SupportDescription",
    "SupportGroup",
    "SupportSource",
    "Surname",
    "Table",
    "TableCount",
    "TableWrap",
    "TableWrapFoot",
    "TableWrapGroup",
    "TableWrapGroupOrientation",
    "TableWrapGroupPosition",
    "TableWrapOrientation",
    "TableWrapPosition",
    "TableFrame",
    "TableRules",
    "Tan",
    "Tanh",
    "Target",
    "Tbody",
    "TbodyAlign",
    "TbodyValign",
    "Td",
    "TdAlign",
    "TdScope",
    "TdValign",
    "Tendsto",
    "Term",
    "TermHead",
    "TexMath",
    "TexMathNotation",
    "TextualForm",
    "Tfoot",
    "TfootAlign",
    "TfootValign",
    "Th",
    "ThAlign",
    "ThScope",
    "ThValign",
    "Thead",
    "TheadAlign",
    "TheadValign",
    "TimeStamp",
    "Times",
    "Title",
    "TitleGroup",
    "TitleEltType",
    "TitleAbstract",
    "Tr",
    "TrAlign",
    "TrValign",
    "TransAbstract",
    "TransSource",
    "TransSubtitle",
    "TransTitle",
    "TransTitleGroup",
    "Transpose",
    "TrueType",
    "TypeType",
    "UnaryElementaryClass",
    "UnaryFunctionalClass",
    "UnaryLinalgClass",
    "UnaryLogicalClass",
    "UnarySetClass",
    "UnaryVeccalcClass",
    "Underline",
    "UnderlineEnd",
    "UnderlineStart",
    "UnderlineToggle",
    "UnionType",
    "UnstructuredKwdGroup",
    "Uplimit",
    "Uri",
    "Variance",
    "Vector",
    "Vectorproduct",
    "VerseGroup",
    "VerseLine",
    "Version",
    "Verticalalign",
    "Volume",
    "VolumeId",
    "VolumeIssueGroup",
    "VolumeSeries",
    "WordCount",
    "X",
    "Xor",
    "Xref",
    "Year",
]
